#
# spec file for package pantheon-camera
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.camera
Name:           pantheon-camera
Version:        8.0.1
Release:        1.3
Summary:        A camera application
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/camera
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pantheon-icons
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libcanberra)
Provides:       elementary-camera = %{version}
Obsoletes:      elementary-camera < %{version}

%description
Camera application designed for the Pantheon desktop

%lang_package

%prep
%autosetup -n camera-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Workflows/Merge: install rust extension for gettext
  * MainWindow: Make headerbar buttons insensitive by default
  * Always use decimal point
  * Updated translations
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-camera
- remove %%suse_update_desktop_file, as it's deprecated
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- enable leap by using datadir/icons
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Update to runtime 8
  * Updated translations
- update to 6.2.2:
  * Replace Gtk.Menu with GLib.Menu
  * Metainfo improvements
- update to 6.2.1:
  * Updated translations
- update to 6.2.0:
  * Support MJPEG cameras
  * Show error in case no camera device is available
  * Updated translations
- update to 6.1.0:
  * Take a photo or video on secondary-click
  * Ensure brightness, contrast, and mirror continue working after taking a photo
  * Wider hardware compatibility (e.g. StarBook Mk V)
  * Ensure photos saved properly
  * Improved performance and reliability
  * Updated translations
- update to 6.0.3:
  * Updated translations
- update to 6.0.2:
  * Resolve issues with cameras being unavailable when multiple cameras are connected
  * Default to a working camera if multiple cameras are connected and one is unavailable
  * Updated translations
- update to 6.0.1:
  * Take full-resolution pictures
  * Fix restoring window size
  * Updated translations
- update to 6.0.0:
  * Switch between multiple cameras
  * Send a notification when recording is finished
  * Add option to mirror the camera
  * Add brightness and contrast adjustment
  * Support the dark style
  * Prevent multiple countdown timers from running at the same time
  * Improved support for camera hardware
  * Updated translations
- update to 1.0.6:
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.5:
  * Delete CODE_OF_CONDUCT.md
  * Create FUNDING.yml
  * Remove unused po files and clean up LINGUAS
  * Use GLib.Action for taking photo and video (#98)
  * HeaderBar: refactor start timeout and timerbutton sensitivity
    (#97)
  * MainWindow: Use GLib.Action for fullscreen (#96)
  * Merge branch 'origin/master' into Weblate.
  * Dumb cap to 640x480 (#95)
* Thu May  2 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.4:
  * Merge branch 'origin/master' into Weblate.
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.3:
  * Update appstream id (#88)
  * Update to latest Houston to pass CI
  * Merge branch 'origin/master' into Weblate
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.2:
  * Use ModeSwitch from Granite (#81)
* Fri Aug 17 2018 avvissu@yandex.by
- Update to 1.0.1:
  * This release includes enhanced translations.
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 1.0:
  * Use GLib.Settings for mode (#71)
  * Delay settings (#70)
  * Add screenshot and OARS (#68)
  * Use mode switch to change photo/video (#64)
* Sat Jun  9 2018 avvissu@yandex.by
- Rename to elementary-camera
- Switch to git from bzr
- Switch to meson
- Rebase dependencies
- Update strings to search icon files
- Remove obsolete macros
- Spec file cleanup
* Tue Jul 11 2017 bwiedemann@suse.com
- Sort file lists to always install the same .svg size
  to fix build-compare (boo#1041090)
* Mon May  1 2017 avvissu@yandex.by
- Update to 0.3.0.1:
  * Fix data files names.
  * Update Translation template.
* Sun Jan 29 2017 jengelh@inai.de
- Make description neutral
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.3
* Mon Aug 22 2016 avvissu@yandex.by
- Fix: icon file not installed
- Spec file cleanup
* Fri May  6 2016 mailaender@opensuse.org
- update to version 0.2.0.1
* Thu Sep  3 2015 and.november@opensuse.org
- initial package (version 0.2) for build.opensuse.org
